@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 """
-    renoir.errors
-    -------------
+renoir.errors
+-------------
 
-    Provides errors.
+Provides errors.
 
-    :copyright: 2014 Giovanni Barillari
-    :license: BSD-3-Clause
+:copyright: 2014 Giovanni Barillari
+:license: BSD-3-Clause
 """
 
 from .helpers import TemplateReference
@@ -15,7 +15,7 @@ from .helpers import TemplateReference
 class TemplateMissingError(Exception):
     def __init__(self, file_path):
         self.path = file_path
-        self.message = f'Template {self.path} not found'
+        self.message = f"Template {self.path} not found"
         super().__init__(self.message)
 
 
@@ -31,9 +31,8 @@ class TemplateError(Exception):
 
 class TemplateSyntaxError(Exception):
     def __init__(self, parser_ctx, exc_type, exc_value, tb):
-        super().__init__('invalid syntax')
-        self._reference = TemplateReference(
-            parser_ctx, exc_type, exc_value, tb)
+        super().__init__("invalid syntax")
+        self._reference = TemplateReference(parser_ctx, exc_type, exc_value, tb)
 
     @property
     def file_path(self):
@@ -46,5 +45,5 @@ class TemplateSyntaxError(Exception):
     @property
     def message(self):
         location = f'File "{self.file_path}", line {self.lineno}'
-        lines = [self.args[0], '  ' + location]
-        return '\n'.join(lines)
+        lines = [self.args[0], "  " + location]
+        return "\n".join(lines)
